@@ -6,13 +6,13 @@ Rubric::DBI::Setup - db initialization routines
 
 =head1 VERSION
 
-version 0.09_05
+version 0.10
 
- $Id: Setup.pm,v 1.4 2005/05/31 03:14:41 rjbs Exp $
+ $Id: Setup.pm,v 1.8 2005/06/07 02:35:41 rjbs Exp $
 
 =cut
 
-our $VERSION = '0.09_05';
+our $VERSION = '0.10';
 
 =head1 SYNOPSIS
 
@@ -85,9 +85,10 @@ sub determine_version {
 
 	if ($version) {
 		if ($version == 6) {
+			# some schemata are broken, and claim 6 on 7
 			eval { $class->dbh->selectall_array("SELECT verification_code FROM users"); };
-			return 7 if $@; # some schemata are broken, and claim 6 on 7
-			return 6;       # other are just fine
+			if ($@) { warn "your db schema label is incorrect; run updatedb"; return 7; }
+			else    { return 6; }
 		} else {
 			return $version;
 		}
@@ -357,7 +358,42 @@ END_SQL
 	$dbh->do($_) for split /\n\n/, $sql;
 };
 
-$from{8} = undef;
+$from{8} = sub {
+	my $sql = <<'END_SQL';
+    CREATE TABLE new_entrytags (
+    id          INTEGER PRIMARY KEY,
+    entry       NOT NULL,
+    tag         NOT NULL,
+    tag_value,
+    UNIQUE(entry, tag)
+	);
+
+	INSERT INTO new_entrytags
+	SELECT id, entry, tag, NULL
+	FROM entrytags;
+
+	DROP TABLE entrytags;
+
+	CREATE TABLE entrytags (
+    id          INTEGER PRIMARY KEY,
+    entry       NOT NULL,
+    tag         NOT NULL,
+    tag_value,
+    UNIQUE(entry, tag)
+	);
+
+	INSERT INTO entrytags
+	SELECT * FROM new_entrytags;
+
+	DROP TABLE new_entrytags;
+
+	UPDATE rubric SET schema_version = 9;
+END_SQL
+
+	$dbh->do($_) for split /\n\n/, $sql;
+};
+
+$from{9} = undef;
 
 sub update_schema {
 	my ($class) = @_;
@@ -367,6 +403,7 @@ sub update_schema {
 		print "updating from version $_...\n";
 		$from{$_}->();
 	}
+	return $class->determine_version;
 }
 
 =head1 TODO
@@ -422,6 +459,7 @@ CREATE TABLE entrytags (
 	id          INTEGER PRIMARY KEY,
 	entry       NOT NULL,
 	tag         NOT NULL,
+  tag_value,
 	UNIQUE(entry, tag)
 );
 
@@ -429,4 +467,4 @@ CREATE TABLE rubric (
 	schema_version NOT NULL
 );
 
-INSERT INTO rubric (schema_version) VALUES (8);
+INSERT INTO rubric (schema_version) VALUES (9);
