@@ -6,7 +6,7 @@ Rubric::Renderer - the rendering interface for Rubric
 
 =head1 VERSION
 
- $Id: Renderer.pm,v 1.9 2005/03/17 02:55:33 rjbs Exp $
+ $Id: Renderer.pm,v 1.11 2005/06/01 23:27:51 rjbs Exp $
 
 =head1 DESCRIPTION
 
@@ -19,8 +19,10 @@ use strict;
 use warnings;
 
 use Carp;
+use Rubric;
 use Rubric::Config;
 use Template;
+use Template::Filters;
 
 =head1 METHODS
 
@@ -77,16 +79,28 @@ my $xml_escape = sub {
 	}
 };
 
+sub _body_filter {
+	my $filters = Template::Filters->new;
+	my $body_filter = $filters->fetch('html_line_break');
+}
+
 sub process { 
 	my ($class, $template, $type, $stash) = @_;
 	return unless $renderer{$type};
 
+	if ($template =~ /entr/ and ($type eq 'html' or $type eq 'rss')) {
+		$stash->{body_filter} = $class->_body_filter;
+	}
+
 	$stash->{xml_escape} = $xml_escape;
+	$stash->{version}    = $Rubric::VERSION;
 
 	$template .= '.' . $renderer{$type}{extension};
 	$renderer{$type}{renderer}->process($template, $stash, \(my $output))
 		or die "Couldn't render template: " . $renderer{$type}{renderer}->error;
+
 	die "template produced no content" unless $output;
+
 	return wantarray
 		? ($renderer{$type}{content_type}, $output)
 		:  $output;
